@@ -1,46 +1,48 @@
-# -*- coding: utf-8 -*-
-from ..Qt import QtCore, QtGui
+import warnings
 
-from .DockDrop import *
+from ..Qt import QtCore, QtGui, QtWidgets
 from ..widgets.VerticalLabel import VerticalLabel
-from ..python2_3 import asUnicode
+from .DockDrop import DockDrop
 
-class Dock(QtGui.QWidget, DockDrop):
+
+class Dock(QtWidgets.QWidget):
 
     sigStretchChanged = QtCore.Signal()
     sigClosed = QtCore.Signal(object)
 
-    def __init__(self, name, area=None, size=(10, 10), widget=None, hideTitle=False, autoOrientation=True, closable=False, fontSize="12px"):
-        QtGui.QWidget.__init__(self)
-        DockDrop.__init__(self)
+    def __init__(self, name, area=None, size=(10, 10), widget=None, hideTitle=False, autoOrientation=True, label=None, **kargs):
+        QtWidgets.QWidget.__init__(self)
+        self.dockdrop = DockDrop(self)
         self._container = None
         self._name = name
         self.area = area
-        self.label = DockLabel(name, self, closable, fontSize)
-        if closable:
+        self.label = label
+        if self.label is None:
+            self.label = DockLabel(name, **kargs)
+        self.label.dock = self
+        if self.label.isClosable():
             self.label.sigCloseClicked.connect(self.close)
         self.labelHidden = False
         self.moveLabel = True  ## If false, the dock is no longer allowed to move the label.
         self.autoOrient = autoOrientation
         self.orientation = 'horizontal'
-        #self.label.setAlignment(QtCore.Qt.AlignHCenter)
-        self.topLayout = QtGui.QGridLayout()
+        #self.label.setAlignment(QtCore.Qt.AlignmentFlag.AlignHCenter)
+        self.topLayout = QtWidgets.QGridLayout()
         self.topLayout.setContentsMargins(0, 0, 0, 0)
         self.topLayout.setSpacing(0)
         self.setLayout(self.topLayout)
         self.topLayout.addWidget(self.label, 0, 1)
-        self.widgetArea = QtGui.QWidget()
+        self.widgetArea = QtWidgets.QWidget()
         self.topLayout.addWidget(self.widgetArea, 1, 1)
-        self.layout = QtGui.QGridLayout()
+        self.layout = QtWidgets.QGridLayout()
         self.layout.setContentsMargins(0, 0, 0, 0)
         self.layout.setSpacing(0)
         self.widgetArea.setLayout(self.layout)
-        self.widgetArea.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+        self.widgetArea.setSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
         self.widgets = []
-        self._container = None
         self.currentRow = 0
         #self.titlePos = 'top'
-        self.raiseOverlay()
+        self.dockdrop.raiseOverlay()
         self.hStyle = """
         Dock > QWidget {
             border: 1px solid #000;
@@ -107,8 +109,7 @@ class Dock(QtGui.QWidget, DockDrop):
         """
         self.label.hide()
         self.labelHidden = True
-        if 'center' in self.allowedAreas:
-            self.allowedAreas.remove('center')
+        self.dockdrop.removeAllowedArea('center')
         self.updateStyle()
 
     def showTitleBar(self):
@@ -117,14 +118,14 @@ class Dock(QtGui.QWidget, DockDrop):
         """
         self.label.show()
         self.labelHidden = False
-        self.allowedAreas.add('center')
+        self.dockdrop.addAllowedArea('center')
         self.updateStyle()
 
     def title(self):
         """
         Gets the text displayed in the title bar for this dock.
         """
-        return asUnicode(self.label.text())
+        return self.label.text()
 
     def setTitle(self, text):
         """
@@ -174,7 +175,7 @@ class Dock(QtGui.QWidget, DockDrop):
 
     def resizeEvent(self, ev):
         self.setOrientation()
-        self.resizeOverlay(self.size())
+        self.dockdrop.resizeOverlay(self.size())
 
     def name(self):
         return self._name
@@ -189,7 +190,7 @@ class Dock(QtGui.QWidget, DockDrop):
         self.currentRow = max(row+1, self.currentRow)
         self.widgets.append(widget)
         self.layout.addWidget(widget, row, col, rowspan, colspan)
-        self.raiseOverlay()
+        self.dockdrop.raiseOverlay()
         
     def startDrag(self):
         self.drag = QtGui.QDrag(self)
@@ -197,7 +198,7 @@ class Dock(QtGui.QWidget, DockDrop):
         self.drag.setMimeData(mime)
         self.widgetArea.setStyleSheet(self.dragStyle)
         self.update()
-        action = self.drag.exec_()
+        action = self.drag.exec() if hasattr(self.drag, 'exec') else self.drag.exec_()
         self.updateStyle()
 
     def float(self):
@@ -209,7 +210,7 @@ class Dock(QtGui.QWidget, DockDrop):
     def containerChanged(self, c):
         if self._container is not None:
             # ask old container to close itself if it is no longer needed
-            self._container.apoptose()
+            self._container.apoptose(propagate=False)
         self._container = c
         if c is None:
             self.area = None
@@ -229,8 +230,12 @@ class Dock(QtGui.QWidget, DockDrop):
 
     def close(self):
         """Remove this dock from the DockArea it lives inside."""
+        if self._container is None:
+            warnings.warn(f"Cannot close dock {self} because it is not open.", RuntimeWarning, stacklevel=2)
+            return
+
         self.setParent(None)
-        QtGui.QLabel.close(self.label)
+        QtWidgets.QLabel.close(self.label)
         self.label.setParent(None)
         self._container.apoptose()
         self._container = None
@@ -239,19 +244,17 @@ class Dock(QtGui.QWidget, DockDrop):
     def __repr__(self):
         return "<Dock %s %s>" % (self.name(), self.stretch())
 
-    ## PySide bug: We need to explicitly redefine these methods
-    ## or else drag/drop events will not be delivered.
     def dragEnterEvent(self, *args):
-        DockDrop.dragEnterEvent(self, *args)
+        self.dockdrop.dragEnterEvent(*args)
 
     def dragMoveEvent(self, *args):
-        DockDrop.dragMoveEvent(self, *args)
+        self.dockdrop.dragMoveEvent(*args)
 
     def dragLeaveEvent(self, *args):
-        DockDrop.dragLeaveEvent(self, *args)
+        self.dockdrop.dragLeaveEvent(*args)
 
     def dropEvent(self, *args):
-        DockDrop.dropEvent(self, *args)
+        self.dockdrop.dropEvent(*args)
 
 
 class DockLabel(VerticalLabel):
@@ -259,22 +262,22 @@ class DockLabel(VerticalLabel):
     sigClicked = QtCore.Signal(object, object)
     sigCloseClicked = QtCore.Signal()
 
-    def __init__(self, text, dock, showCloseButton, fontSize):
+    def __init__(self, text, closable=False, fontSize="12px"):
         self.dim = False
         self.fixedWidth = False
         self.fontSize = fontSize
         VerticalLabel.__init__(self, text, orientation='horizontal', forceWidth=False)
-        self.setAlignment(QtCore.Qt.AlignTop|QtCore.Qt.AlignHCenter)
-        self.dock = dock
+        self.setAlignment(QtCore.Qt.AlignmentFlag.AlignTop|QtCore.Qt.AlignmentFlag.AlignHCenter)
+        self.dock = None
         self.updateStyle()
         self.setAutoFillBackground(False)
         self.mouseMoved = False
 
         self.closeButton = None
-        if showCloseButton:
-            self.closeButton = QtGui.QToolButton(self)
+        if closable:
+            self.closeButton = QtWidgets.QToolButton(self)
             self.closeButton.clicked.connect(self.sigCloseClicked)
-            self.closeButton.setIcon(QtGui.QApplication.style().standardIcon(QtGui.QStyle.SP_TitleBarCloseButton))
+            self.closeButton.setIcon(QtWidgets.QApplication.style().standardIcon(QtWidgets.QStyle.StandardPixmap.SP_TitleBarCloseButton))
 
     def updateStyle(self):
         r = '3px'
@@ -327,16 +330,21 @@ class DockLabel(VerticalLabel):
         VerticalLabel.setOrientation(self, o)
         self.updateStyle()
 
+    def isClosable(self):
+        return self.closeButton is not None
+
     def mousePressEvent(self, ev):
-        self.pressPos = ev.pos()
+        lpos = ev.position() if hasattr(ev, 'position') else ev.localPos()
+        self.pressPos = lpos
         self.mouseMoved = False
         ev.accept()
 
     def mouseMoveEvent(self, ev):
         if not self.mouseMoved:
-            self.mouseMoved = (ev.pos() - self.pressPos).manhattanLength() > QtGui.QApplication.startDragDistance()
+            lpos = ev.position() if hasattr(ev, 'position') else ev.localPos()
+            self.mouseMoved = (lpos - self.pressPos).manhattanLength() > QtWidgets.QApplication.startDragDistance()
 
-        if self.mouseMoved and ev.buttons() == QtCore.Qt.LeftButton:
+        if self.mouseMoved and ev.buttons() == QtCore.Qt.MouseButton.LeftButton:
             self.dock.startDrag()
         ev.accept()
 
@@ -346,7 +354,7 @@ class DockLabel(VerticalLabel):
             self.sigClicked.emit(self, ev)
 
     def mouseDoubleClickEvent(self, ev):
-        if ev.button() == QtCore.Qt.LeftButton:
+        if ev.button() == QtCore.Qt.MouseButton.LeftButton:
             self.dock.float()
 
     def resizeEvent (self, ev):
